@@ -391,7 +391,7 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             list of RequestedAxis which are the info given for the autoplot (for the axes and DataSelection)
         frozen_type : int
             0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them,
-            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch
+            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch, 6 to only allow overlay button
         path_to_image : str
             path to the folder where the image for the animation button is saved
         """
@@ -517,7 +517,7 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             # Freezing the operations (allowing only slice and requested ope)
             for w_slice in self.w_slice_op:
                 current_ope = w_slice.c_operation.currentText()
-                if current_ope != "slice":
+                if current_ope not in ["slice", "overlay"]:
                     w_slice.c_operation.blockSignals(True)
                     w_slice.c_operation.clear()
                     w_slice.c_operation.addItems(["slice", current_ope])
@@ -550,6 +550,19 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                 w_slice.lf_value.setDisabled(True)
                 w_slice.slider.setDisabled(True)
 
+        elif frozen_type == 6:
+            # Freezing the axes
+            self.w_axis_1.c_axis.setDisabled(True)
+            self.w_axis_1.c_action.setDisabled(True)
+            self.w_axis_2.c_axis.setDisabled(True)
+            self.w_axis_2.c_action.setDisabled(True)
+
+            # Freezing the operations
+            for w_slice in self.w_slice_op:
+                w_slice.c_operation.setDisabled(True)
+                w_slice.lf_value.setDisabled(True)
+                w_slice.slider.setDisabled(True)
+
         if len(axes_list) == 1:
             self.w_axis_2.hide()
 
